@@ -34,7 +34,7 @@ static PyObject*
 avl_get_mChannelLayoutTag(PyObject* _self, void* closure __attribute__((__unused__)))
 {
     struct audio_channel_layout* self = (struct audio_channel_layout*)_self;
-    PyObject* result;
+    PyObject*                    result;
 
     Py_BEGIN_CRITICAL_SECTION(self);
     result = Py_BuildValue("I", self->avl_layout->mChannelLayoutTag);
@@ -47,7 +47,7 @@ avl_set_mChannelLayoutTag(PyObject* _self, PyObject* value,
                           void* closure __attribute__((__unused__)))
 {
     struct audio_channel_layout* self = (struct audio_channel_layout*)_self;
-    int result;
+    int                          result;
 
     if (value == NULL) {
         PyErr_SetString(PyExc_ValueError, "Cannot delete 'mChannelLayoutTag'");
@@ -56,7 +56,7 @@ avl_set_mChannelLayoutTag(PyObject* _self, PyObject* value,
 
     Py_BEGIN_CRITICAL_SECTION(self);
     result = PyObjC_PythonToObjC(@encode(unsigned int), value,
-                               &self->avl_layout->mChannelLayoutTag);
+                                 &self->avl_layout->mChannelLayoutTag);
     Py_END_CRITICAL_SECTION();
     return result;
 }
@@ -65,7 +65,7 @@ static PyObject*
 avl_get_mChannelBitmap(PyObject* _self, void* closure __attribute__((__unused__)))
 {
     struct audio_channel_layout* self = (struct audio_channel_layout*)_self;
-    PyObject* result;
+    PyObject*                    result;
 
     Py_BEGIN_CRITICAL_SECTION(self);
     result = Py_BuildValue("I", self->avl_layout->mChannelBitmap);
@@ -78,7 +78,7 @@ avl_set_mChannelBitmap(PyObject* _self, PyObject* value,
                        void* closure __attribute__((__unused__)))
 {
     struct audio_channel_layout* self = (struct audio_channel_layout*)_self;
-    int result;
+    int                          result;
 
     if (value == NULL) {
         PyErr_SetString(PyExc_ValueError, "Cannot delete 'mChannelBitmap'");
@@ -87,7 +87,7 @@ avl_set_mChannelBitmap(PyObject* _self, PyObject* value,
 
     Py_BEGIN_CRITICAL_SECTION(self);
     result = PyObjC_PythonToObjC(@encode(unsigned int), value,
-                               &self->avl_layout->mChannelBitmap);
+                                 &self->avl_layout->mChannelBitmap);
     Py_END_CRITICAL_SECTION();
     return result;
 }
@@ -116,7 +116,7 @@ avl_length(PyObject* self)
 static PyObject*
 avl_get_item(PyObject* _self, Py_ssize_t idx)
 {
-    struct audio_channel_layout* self = ((struct audio_channel_layout*)_self);
+    struct audio_channel_layout* self   = ((struct audio_channel_layout*)_self);
     PyObject*                    result = NULL;
 
     Py_BEGIN_CRITICAL_SECTION(_self);
@@ -157,7 +157,8 @@ avl_get_item(PyObject* _self, Py_ssize_t idx)
     PyTuple_SET_ITEM(self->avl_items, idx, result);
     Py_INCREF(result);
 
-end:(void)0;
+end:
+    (void)0;
     Py_END_CRITICAL_SECTION();
     return result;
 }
